Системные требования — Документация django-ulogin 0.3.0

# Системные требования

- Разработка и тестирование проводилось под управлением OS Ubuntu, Debian. Production-использование — Ubuntu, Debian, RHEL, FreeBSD. Приложение не использует каких-либо специфичных для той или иной операционной системы особенностей языка, поэтому, скорее всего, всё будет работать и на остальных системах, для которых существуют требуемые версии Python
- Интерпретатор Python `2.7+`, `3.4+`, `3.5+`. На других интерпретаторах работоспособность не проверялась
- `Django 1.7+`
- Библиотека python-requests

# Установка

Установка текущей стабильной версии django-ulogin производится из PyPI с помощью утилиты `pip`:

    $ pip install django-ulogin

или `easy_install`:

    $ easy_install django-ulogin

Для установки dev-версии нужно воспользоваться pip:

    $ pip install -e git+github.com/marazmiki/django-ulogin.git#egg=django-ulogin

Все внешние зависимости будут утановлены автоматически